==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/medialive_multiplex_program/MedialiveMultiplexProgramMultiplexProgramSettings.java <==
package com.hashicorp.cdktf.providers.aws.medialive_multiplex_program;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:54.770Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettings")
@software.amazon.jsii.Jsii.Proxy(MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MedialiveMultiplexProgramMultiplexProgramSettings extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#preferred_channel_pipeline MedialiveMultiplexProgram#preferred_channel_pipeline}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPreferredChannelPipeline();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#program_number MedialiveMultiplexProgram#program_number}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getProgramNumber();

    /**
     * service_descriptor block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#service_descriptor MedialiveMultiplexProgram#service_descriptor}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor getServiceDescriptor() {
        return null;
    }

    /**
     * video_settings block.
     * <p>
     * Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#video_settings MedialiveMultiplexProgram#video_settings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings getVideoSettings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MedialiveMultiplexProgramMultiplexProgramSettings> {
        java.lang.String preferredChannelPipeline;
        java.lang.Number programNumber;
        com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor serviceDescriptor;
        com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings videoSettings;

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getPreferredChannelPipeline}
         * @param preferredChannelPipeline Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#preferred_channel_pipeline MedialiveMultiplexProgram#preferred_channel_pipeline}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder preferredChannelPipeline(java.lang.String preferredChannelPipeline) {
            this.preferredChannelPipeline = preferredChannelPipeline;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getProgramNumber}
         * @param programNumber Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#program_number MedialiveMultiplexProgram#program_number}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder programNumber(java.lang.Number programNumber) {
            this.programNumber = programNumber;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getServiceDescriptor}
         * @param serviceDescriptor service_descriptor block.
         *                          Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#service_descriptor MedialiveMultiplexProgram#service_descriptor}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serviceDescriptor(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor serviceDescriptor) {
            this.serviceDescriptor = serviceDescriptor;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getVideoSettings}
         * @param videoSettings video_settings block.
         *                      Docs at Terraform Registry: {&#64;link https://www.terraform.io/docs/providers/aws/r/medialive_multiplex_program#video_settings MedialiveMultiplexProgram#video_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder videoSettings(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings videoSettings) {
            this.videoSettings = videoSettings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MedialiveMultiplexProgramMultiplexProgramSettings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MedialiveMultiplexProgramMultiplexProgramSettings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MedialiveMultiplexProgramMultiplexProgramSettings {
        private final java.lang.String preferredChannelPipeline;
        private final java.lang.Number programNumber;
        private final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor serviceDescriptor;
        private final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings videoSettings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.preferredChannelPipeline = software.amazon.jsii.Kernel.get(this, "preferredChannelPipeline", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.programNumber = software.amazon.jsii.Kernel.get(this, "programNumber", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.serviceDescriptor = software.amazon.jsii.Kernel.get(this, "serviceDescriptor", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor.class));
            this.videoSettings = software.amazon.jsii.Kernel.get(this, "videoSettings", software.amazon.jsii.NativeType.forClass(com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.preferredChannelPipeline = java.util.Objects.requireNonNull(builder.preferredChannelPipeline, "preferredChannelPipeline is required");
            this.programNumber = java.util.Objects.requireNonNull(builder.programNumber, "programNumber is required");
            this.serviceDescriptor = builder.serviceDescriptor;
            this.videoSettings = builder.videoSettings;
        }

        @Override
        public final java.lang.String getPreferredChannelPipeline() {
            return this.preferredChannelPipeline;
        }

        @Override
        public final java.lang.Number getProgramNumber() {
            return this.programNumber;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor getServiceDescriptor() {
            return this.serviceDescriptor;
        }

        @Override
        public final com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings getVideoSettings() {
            return this.videoSettings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("preferredChannelPipeline", om.valueToTree(this.getPreferredChannelPipeline()));
            data.set("programNumber", om.valueToTree(this.getProgramNumber()));
            if (this.getServiceDescriptor() != null) {
                data.set("serviceDescriptor", om.valueToTree(this.getServiceDescriptor()));
            }
            if (this.getVideoSettings() != null) {
                data.set("videoSettings", om.valueToTree(this.getVideoSettings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy that = (MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy) o;

            if (!preferredChannelPipeline.equals(that.preferredChannelPipeline)) return false;
            if (!programNumber.equals(that.programNumber)) return false;
            if (this.serviceDescriptor != null ? !this.serviceDescriptor.equals(that.serviceDescriptor) : that.serviceDescriptor != null) return false;
            return this.videoSettings != null ? this.videoSettings.equals(that.videoSettings) : that.videoSettings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.preferredChannelPipeline.hashCode();
            result = 31 * result + (this.programNumber.hashCode());
            result = 31 * result + (this.serviceDescriptor != null ? this.serviceDescriptor.hashCode() : 0);
            result = 31 * result + (this.videoSettings != null ? this.videoSettings.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/medialive_multiplex_program/MedialiveMultiplexProgramMultiplexProgramSettings.java <==
package com.hashicorp.cdktf.providers.aws.medialive_multiplex_program;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:10.775Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettings")
@software.amazon.jsii.Jsii.Proxy(MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface MedialiveMultiplexProgramMultiplexProgramSettings extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#preferred_channel_pipeline MedialiveMultiplexProgram#preferred_channel_pipeline}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getPreferredChannelPipeline();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#program_number MedialiveMultiplexProgram#program_number}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Number getProgramNumber();

    /**
     * service_descriptor block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#service_descriptor MedialiveMultiplexProgram#service_descriptor}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getServiceDescriptor() {
        return null;
    }

    /**
     * video_settings block.
     * <p>
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#video_settings MedialiveMultiplexProgram#video_settings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getVideoSettings() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<MedialiveMultiplexProgramMultiplexProgramSettings> {
        java.lang.String preferredChannelPipeline;
        java.lang.Number programNumber;
        java.lang.Object serviceDescriptor;
        java.lang.Object videoSettings;

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getPreferredChannelPipeline}
         * @param preferredChannelPipeline Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#preferred_channel_pipeline MedialiveMultiplexProgram#preferred_channel_pipeline}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder preferredChannelPipeline(java.lang.String preferredChannelPipeline) {
            this.preferredChannelPipeline = preferredChannelPipeline;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getProgramNumber}
         * @param programNumber Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#program_number MedialiveMultiplexProgram#program_number}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder programNumber(java.lang.Number programNumber) {
            this.programNumber = programNumber;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getServiceDescriptor}
         * @param serviceDescriptor service_descriptor block.
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#service_descriptor MedialiveMultiplexProgram#service_descriptor}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serviceDescriptor(com.hashicorp.cdktf.IResolvable serviceDescriptor) {
            this.serviceDescriptor = serviceDescriptor;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getServiceDescriptor}
         * @param serviceDescriptor service_descriptor block.
         *                          Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#service_descriptor MedialiveMultiplexProgram#service_descriptor}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder serviceDescriptor(java.util.List<? extends com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsServiceDescriptor> serviceDescriptor) {
            this.serviceDescriptor = serviceDescriptor;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getVideoSettings}
         * @param videoSettings video_settings block.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#video_settings MedialiveMultiplexProgram#video_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder videoSettings(com.hashicorp.cdktf.IResolvable videoSettings) {
            this.videoSettings = videoSettings;
            return this;
        }

        /**
         * Sets the value of {@link MedialiveMultiplexProgramMultiplexProgramSettings#getVideoSettings}
         * @param videoSettings video_settings block.
         *                      Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/medialive_multiplex_program#video_settings MedialiveMultiplexProgram#video_settings}
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder videoSettings(java.util.List<? extends com.hashicorp.cdktf.providers.aws.medialive_multiplex_program.MedialiveMultiplexProgramMultiplexProgramSettingsVideoSettings> videoSettings) {
            this.videoSettings = videoSettings;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link MedialiveMultiplexProgramMultiplexProgramSettings}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public MedialiveMultiplexProgramMultiplexProgramSettings build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link MedialiveMultiplexProgramMultiplexProgramSettings}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements MedialiveMultiplexProgramMultiplexProgramSettings {
        private final java.lang.String preferredChannelPipeline;
        private final java.lang.Number programNumber;
        private final java.lang.Object serviceDescriptor;
        private final java.lang.Object videoSettings;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.preferredChannelPipeline = software.amazon.jsii.Kernel.get(this, "preferredChannelPipeline", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.programNumber = software.amazon.jsii.Kernel.get(this, "programNumber", software.amazon.jsii.NativeType.forClass(java.lang.Number.class));
            this.serviceDescriptor = software.amazon.jsii.Kernel.get(this, "serviceDescriptor", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
            this.videoSettings = software.amazon.jsii.Kernel.get(this, "videoSettings", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.preferredChannelPipeline = java.util.Objects.requireNonNull(builder.preferredChannelPipeline, "preferredChannelPipeline is required");
            this.programNumber = java.util.Objects.requireNonNull(builder.programNumber, "programNumber is required");
            this.serviceDescriptor = builder.serviceDescriptor;
            this.videoSettings = builder.videoSettings;
        }

        @Override
        public final java.lang.String getPreferredChannelPipeline() {
            return this.preferredChannelPipeline;
        }

        @Override
        public final java.lang.Number getProgramNumber() {
            return this.programNumber;
        }

        @Override
        public final java.lang.Object getServiceDescriptor() {
            return this.serviceDescriptor;
        }

        @Override
        public final java.lang.Object getVideoSettings() {
            return this.videoSettings;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("preferredChannelPipeline", om.valueToTree(this.getPreferredChannelPipeline()));
            data.set("programNumber", om.valueToTree(this.getProgramNumber()));
            if (this.getServiceDescriptor() != null) {
                data.set("serviceDescriptor", om.valueToTree(this.getServiceDescriptor()));
            }
            if (this.getVideoSettings() != null) {
                data.set("videoSettings", om.valueToTree(this.getVideoSettings()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.medialiveMultiplexProgram.MedialiveMultiplexProgramMultiplexProgramSettings"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy that = (MedialiveMultiplexProgramMultiplexProgramSettings.Jsii$Proxy) o;

            if (!preferredChannelPipeline.equals(that.preferredChannelPipeline)) return false;
            if (!programNumber.equals(that.programNumber)) return false;
            if (this.serviceDescriptor != null ? !this.serviceDescriptor.equals(that.serviceDescriptor) : that.serviceDescriptor != null) return false;
            return this.videoSettings != null ? this.videoSettings.equals(that.videoSettings) : that.videoSettings == null;
        }

        @Override
        public final int hashCode() {
            int result = this.preferredChannelPipeline.hashCode();
            result = 31 * result + (this.programNumber.hashCode());
            result = 31 * result + (this.serviceDescriptor != null ? this.serviceDescriptor.hashCode() : 0);
            result = 31 * result + (this.videoSettings != null ? this.videoSettings.hashCode() : 0);
            return result;
        }
    }
}
